import {StyleSheet, Text, View, FlatList, Image} from 'react-native';
import {SampleJoke} from "../model/SampleJoke";
import {CustomJoke} from "../model/CustomJoke";
import {darksalmonColor, whiteColor, greyColor, indigoColor} from "../assets/Theme";
import {Colors} from "react-native/Libraries/NewAppScreen";

type JokeListItemProps = {
    jokes: CustomJoke[] | SampleJoke[];
};

export default function JokeListItem(props: JokeListItemProps) {
    const renderItem = ({ item }: { item: CustomJoke | SampleJoke }) => (
        <View style={styles.rowContainer}>
            <View style={styles.color}/>
            <Image source={{ uri: item.image }} style={styles.image} />
            <View style={styles.columnContainer}>
                <Text style={styles.text}>Résumé de la blague</Text>
                <Text style={styles.text}>{item.description()}</Text>
                <View style={styles.bottomContainer}>
                    <Text style={{color:'white'}}>{item.type}</Text>
                </View>
            </View>
        </View>
    );

    return (
        <FlatList
            data={props.jokes}
            keyExtractor={(item) => item.id.toString()}
            renderItem={renderItem}
        />
    );
}

const styles = StyleSheet.create({
    rowContainer: {
        flexDirection: "row",
        marginHorizontal: "5%",
        marginBottom:7,
        marginTop:7,
        paddingVertical: 10,
        backgroundColor: indigoColor,
        width:'90%',
        height:150,
        justifyContent: 'space-between',
        alignItems: 'center',
    },
    color: {
        flex: 0,
        backgroundColor: darksalmonColor,
        height: 150,
        width:15,
    },
    image: {
        width: '40%',
        height: 150,
        flex: 1
    },
    columnContainer: {
        flexDirection: "column",
        marginLeft: 20,
        marginRight: 20,
        width: '60%',
        flex: 2,
        justifyContent: 'space-between',
    },
    text: {
        color:whiteColor,
        paddingBottom: 7,
        paddingTop: 7,
        fontSize: 16,
    },
    bottomContainer: {
        backgroundColor: greyColor,
        paddingVertical: 5,
        paddingHorizontal: 10,
        borderRadius: 20,
        width : 150,
        alignItems : 'center'
    }
});